Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppsClient ¶
type AppsClient struct {
// contains filtered or unexported fields
}
AppsClient is used to interact with features provided by the apps group.
func New ¶
func New(c rest.Interface) *AppsClient
New creates a new AppsClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AppsClient, error)
NewForConfig creates a new AppsClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AppsClient
NewForConfigOrDie creates a new AppsClient for the given config and panics if there is an error in the config.
func (*AppsClient) ControllerRevisions ¶
func (c *AppsClient) ControllerRevisions(namespace string) ControllerRevisionInterface
func (*AppsClient) RESTClient ¶
func (c *AppsClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*AppsClient) StatefulSets ¶
func (c *AppsClient) StatefulSets(namespace string) StatefulSetInterface
type AppsInterface ¶
type AppsInterface interface {
RESTClient() rest.Interface
ControllerRevisionsGetter
StatefulSetsGetter
}
type ControllerRevisionExpansion ¶
type ControllerRevisionExpansion interface{}
type ControllerRevisionInterface ¶
type ControllerRevisionInterface interface {
Create(*apps.ControllerRevision) (*apps.ControllerRevision, error)
Update(*apps.ControllerRevision) (*apps.ControllerRevision, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*apps.ControllerRevision, error)
List(opts v1.ListOptions) (*apps.ControllerRevisionList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *apps.ControllerRevision, err error)
ControllerRevisionExpansion
}
ControllerRevisionInterface has methods to work with ControllerRevision resources.
type ControllerRevisionsGetter ¶
type ControllerRevisionsGetter interface {
ControllerRevisions(namespace string) ControllerRevisionInterface
}
ControllerRevisionsGetter has a method to return a ControllerRevisionInterface. A group's client should implement this interface.
type StatefulSetExpansion ¶
type StatefulSetExpansion interface{}
type StatefulSetInterface ¶
type StatefulSetInterface interface {
Create(*apps.StatefulSet) (*apps.StatefulSet, error)
Update(*apps.StatefulSet) (*apps.StatefulSet, error)
UpdateStatus(*apps.StatefulSet) (*apps.StatefulSet, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*apps.StatefulSet, error)
List(opts v1.ListOptions) (*apps.StatefulSetList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *apps.StatefulSet, err error)
GetScale(statefulSetName string, options v1.GetOptions) (*autoscaling.Scale, error)
UpdateScale(statefulSetName string, scale *autoscaling.Scale) (*autoscaling.Scale, error)
StatefulSetExpansion
}
StatefulSetInterface has methods to work with StatefulSet resources.
type StatefulSetsGetter ¶
type StatefulSetsGetter interface {
StatefulSets(namespace string) StatefulSetInterface
}
StatefulSetsGetter has a method to return a StatefulSetInterface. A group's client should implement this interface.