Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type DaemonSetExpansion
- type DaemonSetInterface
- type DaemonSetsGetter
- type DeploymentExpansion
- type DeploymentInterface
- type DeploymentsGetter
- type ExtensionsClient
- func (c *ExtensionsClient) DaemonSets(namespace string) DaemonSetInterface
- func (c *ExtensionsClient) Deployments(namespace string) DeploymentInterface
- func (c *ExtensionsClient) Ingresses(namespace string) IngressInterface
- func (c *ExtensionsClient) PodSecurityPolicies() PodSecurityPolicyInterface
- func (c *ExtensionsClient) RESTClient() rest.Interface
- func (c *ExtensionsClient) ReplicaSets(namespace string) ReplicaSetInterface
- type ExtensionsInterface
- type IngressExpansion
- type IngressInterface
- type IngressesGetter
- type PodSecurityPoliciesGetter
- type PodSecurityPolicyExpansion
- type PodSecurityPolicyInterface
- type ReplicaSetExpansion
- type ReplicaSetInterface
- type ReplicaSetsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DaemonSetExpansion ¶
type DaemonSetExpansion interface{}
type DaemonSetInterface ¶
type DaemonSetInterface interface {
Create(*extensions.DaemonSet) (*extensions.DaemonSet, error)
Update(*extensions.DaemonSet) (*extensions.DaemonSet, error)
UpdateStatus(*extensions.DaemonSet) (*extensions.DaemonSet, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*extensions.DaemonSet, error)
List(opts v1.ListOptions) (*extensions.DaemonSetList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *extensions.DaemonSet, err error)
DaemonSetExpansion
}
DaemonSetInterface has methods to work with DaemonSet resources.
type DaemonSetsGetter ¶
type DaemonSetsGetter interface {
DaemonSets(namespace string) DaemonSetInterface
}
DaemonSetsGetter has a method to return a DaemonSetInterface. A group's client should implement this interface.
type DeploymentExpansion ¶
type DeploymentExpansion interface {
Rollback(*extensions.DeploymentRollback) error
}
The DeploymentExpansion interface allows manually adding extra methods to the DeploymentInterface.
type DeploymentInterface ¶
type DeploymentInterface interface {
Create(*extensions.Deployment) (*extensions.Deployment, error)
Update(*extensions.Deployment) (*extensions.Deployment, error)
UpdateStatus(*extensions.Deployment) (*extensions.Deployment, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*extensions.Deployment, error)
List(opts v1.ListOptions) (*extensions.DeploymentList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *extensions.Deployment, err error)
GetScale(deploymentName string, options v1.GetOptions) (*autoscaling.Scale, error)
UpdateScale(deploymentName string, scale *autoscaling.Scale) (*autoscaling.Scale, error)
DeploymentExpansion
}
DeploymentInterface has methods to work with Deployment resources.
type DeploymentsGetter ¶
type DeploymentsGetter interface {
Deployments(namespace string) DeploymentInterface
}
DeploymentsGetter has a method to return a DeploymentInterface. A group's client should implement this interface.
type ExtensionsClient ¶
type ExtensionsClient struct {
// contains filtered or unexported fields
}
ExtensionsClient is used to interact with features provided by the extensions group.
func New ¶
func New(c rest.Interface) *ExtensionsClient
New creates a new ExtensionsClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ExtensionsClient, error)
NewForConfig creates a new ExtensionsClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ExtensionsClient
NewForConfigOrDie creates a new ExtensionsClient for the given config and panics if there is an error in the config.
func (*ExtensionsClient) DaemonSets ¶
func (c *ExtensionsClient) DaemonSets(namespace string) DaemonSetInterface
func (*ExtensionsClient) Deployments ¶
func (c *ExtensionsClient) Deployments(namespace string) DeploymentInterface
func (*ExtensionsClient) Ingresses ¶
func (c *ExtensionsClient) Ingresses(namespace string) IngressInterface
func (*ExtensionsClient) PodSecurityPolicies ¶
func (c *ExtensionsClient) PodSecurityPolicies() PodSecurityPolicyInterface
func (*ExtensionsClient) RESTClient ¶
func (c *ExtensionsClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*ExtensionsClient) ReplicaSets ¶
func (c *ExtensionsClient) ReplicaSets(namespace string) ReplicaSetInterface
type ExtensionsInterface ¶
type ExtensionsInterface interface {
RESTClient() rest.Interface
DaemonSetsGetter
DeploymentsGetter
IngressesGetter
PodSecurityPoliciesGetter
ReplicaSetsGetter
}
type IngressExpansion ¶
type IngressExpansion interface{}
type IngressInterface ¶
type IngressInterface interface {
Create(*extensions.Ingress) (*extensions.Ingress, error)
Update(*extensions.Ingress) (*extensions.Ingress, error)
UpdateStatus(*extensions.Ingress) (*extensions.Ingress, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*extensions.Ingress, error)
List(opts v1.ListOptions) (*extensions.IngressList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *extensions.Ingress, err error)
IngressExpansion
}
IngressInterface has methods to work with Ingress resources.
type IngressesGetter ¶
type IngressesGetter interface {
Ingresses(namespace string) IngressInterface
}
IngressesGetter has a method to return a IngressInterface. A group's client should implement this interface.
type PodSecurityPoliciesGetter ¶
type PodSecurityPoliciesGetter interface {
PodSecurityPolicies() PodSecurityPolicyInterface
}
PodSecurityPoliciesGetter has a method to return a PodSecurityPolicyInterface. A group's client should implement this interface.
type PodSecurityPolicyExpansion ¶
type PodSecurityPolicyExpansion interface{}
type PodSecurityPolicyInterface ¶
type PodSecurityPolicyInterface interface {
Create(*extensions.PodSecurityPolicy) (*extensions.PodSecurityPolicy, error)
Update(*extensions.PodSecurityPolicy) (*extensions.PodSecurityPolicy, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*extensions.PodSecurityPolicy, error)
List(opts v1.ListOptions) (*extensions.PodSecurityPolicyList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *extensions.PodSecurityPolicy, err error)
PodSecurityPolicyExpansion
}
PodSecurityPolicyInterface has methods to work with PodSecurityPolicy resources.
type ReplicaSetExpansion ¶
type ReplicaSetExpansion interface{}
type ReplicaSetInterface ¶
type ReplicaSetInterface interface {
Create(*extensions.ReplicaSet) (*extensions.ReplicaSet, error)
Update(*extensions.ReplicaSet) (*extensions.ReplicaSet, error)
UpdateStatus(*extensions.ReplicaSet) (*extensions.ReplicaSet, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*extensions.ReplicaSet, error)
List(opts v1.ListOptions) (*extensions.ReplicaSetList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *extensions.ReplicaSet, err error)
GetScale(replicaSetName string, options v1.GetOptions) (*autoscaling.Scale, error)
UpdateScale(replicaSetName string, scale *autoscaling.Scale) (*autoscaling.Scale, error)
ReplicaSetExpansion
}
ReplicaSetInterface has methods to work with ReplicaSet resources.
type ReplicaSetsGetter ¶
type ReplicaSetsGetter interface {
ReplicaSets(namespace string) ReplicaSetInterface
}
ReplicaSetsGetter has a method to return a ReplicaSetInterface. A group's client should implement this interface.