Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FischerExpansion ¶
type FischerExpansion interface{}
type FischerInterface ¶
type FischerInterface interface {
Create(*wardle.Fischer) (*wardle.Fischer, error)
Update(*wardle.Fischer) (*wardle.Fischer, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*wardle.Fischer, error)
List(opts v1.ListOptions) (*wardle.FischerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *wardle.Fischer, err error)
FischerExpansion
}
FischerInterface has methods to work with Fischer resources.
type FischersGetter ¶
type FischersGetter interface {
Fischers() FischerInterface
}
FischersGetter has a method to return a FischerInterface. A group's client should implement this interface.
type FlunderExpansion ¶
type FlunderExpansion interface{}
type FlunderInterface ¶
type FlunderInterface interface {
Create(*wardle.Flunder) (*wardle.Flunder, error)
Update(*wardle.Flunder) (*wardle.Flunder, error)
UpdateStatus(*wardle.Flunder) (*wardle.Flunder, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*wardle.Flunder, error)
List(opts v1.ListOptions) (*wardle.FlunderList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *wardle.Flunder, err error)
FlunderExpansion
}
FlunderInterface has methods to work with Flunder resources.
type FlundersGetter ¶
type FlundersGetter interface {
Flunders(namespace string) FlunderInterface
}
FlundersGetter has a method to return a FlunderInterface. A group's client should implement this interface.
type WardleClient ¶
type WardleClient struct {
// contains filtered or unexported fields
}
WardleClient is used to interact with features provided by the wardle.k8s.io group.
func New ¶
func New(c rest.Interface) *WardleClient
New creates a new WardleClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*WardleClient, error)
NewForConfig creates a new WardleClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *WardleClient
NewForConfigOrDie creates a new WardleClient for the given config and panics if there is an error in the config.
func (*WardleClient) Fischers ¶
func (c *WardleClient) Fischers() FischerInterface
func (*WardleClient) Flunders ¶
func (c *WardleClient) Flunders(namespace string) FlunderInterface
func (*WardleClient) RESTClient ¶
func (c *WardleClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type WardleInterface ¶
type WardleInterface interface {
RESTClient() rest.Interface
FischersGetter
FlundersGetter
}