Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FischerExpansion ¶
type FischerExpansion interface{}
type FischerInterface ¶
type FischerInterface interface {
Create(*v1alpha1.Fischer) (*v1alpha1.Fischer, error)
Update(*v1alpha1.Fischer) (*v1alpha1.Fischer, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Fischer, error)
List(opts v1.ListOptions) (*v1alpha1.FischerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Fischer, err error)
FischerExpansion
}
FischerInterface has methods to work with Fischer resources.
type FischersGetter ¶
type FischersGetter interface {
Fischers() FischerInterface
}
FischersGetter has a method to return a FischerInterface. A group's client should implement this interface.
type FlunderExpansion ¶
type FlunderExpansion interface{}
type FlunderInterface ¶
type FlunderInterface interface {
Create(*v1alpha1.Flunder) (*v1alpha1.Flunder, error)
Update(*v1alpha1.Flunder) (*v1alpha1.Flunder, error)
UpdateStatus(*v1alpha1.Flunder) (*v1alpha1.Flunder, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Flunder, error)
List(opts v1.ListOptions) (*v1alpha1.FlunderList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Flunder, err error)
FlunderExpansion
}
FlunderInterface has methods to work with Flunder resources.
type FlundersGetter ¶
type FlundersGetter interface {
Flunders(namespace string) FlunderInterface
}
FlundersGetter has a method to return a FlunderInterface. A group's client should implement this interface.
type WardleV1alpha1Client ¶
type WardleV1alpha1Client struct {
// contains filtered or unexported fields
}
WardleV1alpha1Client is used to interact with features provided by the wardle.k8s.io group.
func New ¶
func New(c rest.Interface) *WardleV1alpha1Client
New creates a new WardleV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*WardleV1alpha1Client, error)
NewForConfig creates a new WardleV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *WardleV1alpha1Client
NewForConfigOrDie creates a new WardleV1alpha1Client for the given config and panics if there is an error in the config.
func (*WardleV1alpha1Client) Fischers ¶
func (c *WardleV1alpha1Client) Fischers() FischerInterface
func (*WardleV1alpha1Client) Flunders ¶
func (c *WardleV1alpha1Client) Flunders(namespace string) FlunderInterface
func (*WardleV1alpha1Client) RESTClient ¶
func (c *WardleV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type WardleV1alpha1Interface ¶
type WardleV1alpha1Interface interface {
RESTClient() rest.Interface
FischersGetter
FlundersGetter
}